@@ -1,4 +1,5 @@
-from subprocess import DEVNULL, CalledProcessError, run
+from subprocess import DEVNULL, PIPE, CalledProcessError, CompletedProcess, run
+from sys import exit
 
 import click
 
@@ -19,19 +20,21 @@ def run_command(
     quiet: bool = False,
     check: bool = False,
     error_message: str = "Error!",
-) -> None:
+    capture_output: bool = False,
+) -> CompletedProcess:
     try:
-        run(
+        return run(
             command,
             shell=True,
             check=check,
-            stdout=DEVNULL if quiet else None,
+            stdout=DEVNULL if quiet else PIPE if capture_output else None,
             stderr=DEVNULL if not check and quiet else None,
         )
     except CalledProcessError:
         if check:
             explain_error(error_message)
-            raise
+
+    exit(1)
 
 
 def docker(
@@ -39,7 +42,12 @@ def docker(
     quiet: bool = False,
     check: bool = False,
     error_message: str = "Error!",
-) -> None:
-    run_command(
-        f"sudo docker {command}", quiet=quiet, check=check, error_message=error_message
+    capture_output: bool = False,
+) -> CompletedProcess:
+    return run_command(
+        f"sudo docker {command}",
+        quiet=quiet,
+        check=check,
+        error_message=error_message,
+        capture_output=capture_output,
     )
